summaryrefslogtreecommitdiffstats
path: root/tderesources/scalix
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:21:18 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:21:18 -0500
commita637b0877543118dd023c0ecc7e241eb7168d115 (patch)
tree94c72f7ab55db536f32dbb5131d000bc5163e1c6 /tderesources/scalix
parent3c297a53e980c6270ff2c05ec0d3a917a9b181c1 (diff)
downloadtdepim-a637b0877543118dd023c0ecc7e241eb7168d115.tar.gz
tdepim-a637b0877543118dd023c0ecc7e241eb7168d115.zip
Rename KWallet to TDEWallet
Diffstat (limited to 'tderesources/scalix')
-rw-r--r--tderesources/scalix/scalixadmin/passwordpage.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tderesources/scalix/scalixadmin/passwordpage.cpp b/tderesources/scalix/scalixadmin/passwordpage.cpp
index 4a13b700..38262725 100644
--- a/tderesources/scalix/scalixadmin/passwordpage.cpp
+++ b/tderesources/scalix/scalixadmin/passwordpage.cpp
@@ -162,13 +162,13 @@ void PasswordPage::finished( TDEIO::Job* job )
// Save only if the user choose it before
bool storePassword = group.readBoolEntry( "store-passwd", false );
if ( storePassword ) {
- // First try to store in KWallet
- if ( KWallet::Wallet::isEnabled() ) {
+ // First try to store in TDEWallet
+ if ( TDEWallet::Wallet::isEnabled() ) {
WId window = 0;
if ( tqApp->activeWindow() )
window = tqApp->activeWindow()->winId();
- KWallet::Wallet *wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), window );
+ TDEWallet::Wallet *wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet(), window );
if ( wallet ) {
if ( !wallet->hasFolder( "kmail" ) )
wallet->createFolder( "kmail" );